@@ -1,4 +1,5 @@
 import json
+import os
 
 from typing import Mapping
 from dataverk.abc.base import DataverkBase
@@ -24,17 +25,17 @@ class PackagePublisher(DataverkBase):
 
         :return: None
         """
-        bucket_type = self._datapackage_metadata.get("store")
+        bucket_type = self._datapackage_metadata.get('store', StorageType.LOCAL)
         datapackage_id = self._datapackage_metadata.get("id")
         storage_connector = get_storage_connector(
             storage_type=StorageType(bucket_type),
-            bucket_name=self._datapackage_metadata.get("bucket"),
+            bucket_name=self._datapackage_metadata["bucket"],
             settings=self._settings_store,
         )
 
         self.log.info(
             f"Publishing datapackage {self._datapackage_metadata.get('title')} "
-            f"to bucket {self._datapackage_metadata.get('bucket')}"
+            f"to bucket {self._datapackage_metadata['bucket']}"
         )
 
         PackagePublisher._upload_datapackage_metadata(
@@ -69,10 +70,10 @@ class PackagePublisher(DataverkBase):
         datapackage_metadata: Mapping,
         resources: dict,
     ) -> None:
-        for filename, resource in resources.items():
+        for resource in resources:
             storage_connector.write(
                 data=resource.get("data"),
-                destination_blob_name=f"{datapackage_id}/resources/{filename}",
+                destination_blob_name=f"{datapackage_id}/{resource.get('name')}",
                 metadata=datapackage_metadata,
                 fmt=resource.get("format"),
             )
